@@ -17,6 +17,7 @@
 # HyperKitty.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Author: Aamir Khan <syst3m.w0rm@gmail.com>
+# Author: Aurelien Bompard <abompard@fedoraproject.org>
 #
 
 class PaginationMiddleware(object):
@@ -35,7 +36,7 @@ class PaginationMiddleware(object):
 # http://stackoverflow.com/questions/2799450/django-https-for-just-login-page
 
 from django.conf import settings
-from django.http import HttpResponseRedirect, HttpResponsePermanentRedirect
+from django.http import HttpResponsePermanentRedirect
 
 SSL = 'SSL'
 
@@ -69,3 +70,23 @@ class SSLRedirect(object):
         """Django can't perform a SSL redirect while maintaining POST data.
            Please structure your views so that redirects only occur during GETs."""
         return HttpResponsePermanentRedirect(newurl)
+
+
+
+# https://docs.djangoproject.com/en/dev/topics/i18n/timezones/
+
+from django.utils import timezone
+from django.core.exceptions import ObjectDoesNotExist
+from hyperkitty.models import UserProfile
+
+class TimezoneMiddleware(object):
+
+    def process_request(self, request):
+        if not request.user.is_authenticated():
+            return
+        try:
+            user_profile = request.user.get_profile()
+        except ObjectDoesNotExist:
+            return
+        if user_profile.timezone:
+            timezone.activate(user_profile.timezone)
