@@ -21,17 +21,19 @@
 
 from django.db import models
 from django.contrib.auth.models import User
-from django.conf import settings
 from django.contrib import admin
 
+import pytz
+from paintstore.fields import ColorPickerField
+
 
 
 class Rating(models.Model):
     # @TODO: instead of list_address, user list model from kittystore?
-    list_address = models.CharField(max_length=255)
+    list_address = models.CharField(max_length=255, db_index=True)
 
     # @TODO: instead of messsageid, use message model from kittystore?
-    messageid = models.CharField(max_length=100)
+    messageid = models.CharField(max_length=100, db_index=True)
 
     user = models.ForeignKey(User)
 
@@ -54,6 +56,8 @@ class UserProfile(models.Model):
     user = models.OneToOneField(User)
 
     karma = models.IntegerField(default=1)
+    TIMEZONES = [ (tz, tz) for tz in pytz.common_timezones ]
+    timezone = models.CharField(max_length=100, choices=TIMEZONES, default=u"")
 
     def __unicode__(self):
         """Unicode representation"""
@@ -62,11 +66,10 @@ class UserProfile(models.Model):
 
 class Tag(models.Model):
     # @TODO: instead of list_address, user list model from kittystore?
-    list_address = models.CharField(max_length=255)
-
+    list_address = models.CharField(max_length=255, db_index=True)
     # @TODO: instead of threadid, use thread model from kittystore?
-    threadid = models.CharField(max_length=100)
-
+    threadid = models.CharField(max_length=100, db_index=True)
+    user = models.ForeignKey(User)
     tag = models.CharField(max_length=255)
 
     def __unicode__(self):
@@ -78,8 +81,8 @@ admin.site.register(Tag)
 
 
 class Favorite(models.Model):
-    list_address = models.CharField(max_length=255)
-    threadid = models.CharField(max_length=100)
+    list_address = models.CharField(max_length=255, db_index=True)
+    threadid = models.CharField(max_length=100, db_index=True)
     user = models.ForeignKey(User)
 
     def __unicode__(self):
@@ -88,3 +91,37 @@ class Favorite(models.Model):
                 unicode(self.user))
 
 admin.site.register(Favorite)
+
+
+class LastView(models.Model):
+    list_address = models.CharField(max_length=255, db_index=True)
+    threadid = models.CharField(max_length=100, db_index=True)
+    user = models.ForeignKey(User)
+    view_date = models.DateTimeField(auto_now=True)
+
+    def __unicode__(self):
+        """Unicode representation"""
+        return u"Last view of %s by user %s was %s" % (unicode(self.threadid),
+                unicode(self.user), self.view_date.isoformat())
+
+admin.site.register(LastView)
+
+
+class ThreadCategory(models.Model):
+    name = models.CharField(max_length=255, db_index=True, unique=True)
+    color = ColorPickerField()
+
+    class Meta:
+        verbose_name_plural = "Thread categories"
+
+    def __unicode__(self):
+        """Unicode representation"""
+        return u'Category "%s"' % (unicode(self.name))
+
+class ThreadCategoryAdmin(admin.ModelAdmin):
+    def save_model(self, request, obj, form, change):
+        obj.name = obj.name.lower()
+        return super(ThreadCategoryAdmin, self).save_model(
+                     request, obj, form, change)
+
+admin.site.register(ThreadCategory, ThreadCategoryAdmin)
