@@ -21,12 +21,11 @@
 #
 
 from django.conf.urls import patterns, include, url
-from django.conf import settings
 from django.views.generic.base import TemplateView
-from api import ListResource, EmailResource, ThreadResource, SearchResource
+from hyperkitty.api import ListResource, EmailResource, ThreadResource, SearchResource
+from hyperkitty.api import TagResource
 
 from django.contrib.staticfiles.urls import staticfiles_urlpatterns
-from django.contrib.auth.views import login as login_view
 from django.contrib.auth.views import logout as logout_view
 
 # Uncomment the next two lines to enable the admin:
@@ -44,10 +43,11 @@ urlpatterns = patterns('hyperkitty.views',
     url(r'^lists-properties$', 'pages.list_properties', name='list_properties'),
 
     # Account
-    #url(r'^accounts/login/$', login_view, {'template_name': 'login.html', 'SSL': True}, name='user_login'),
     url(r'^accounts/login/$', 'accounts.login_view', {'template_name': 'login.html', 'SSL': True}, name='user_login'),
     url(r'^accounts/logout/$', logout_view, {'next_page': '/'}, name='user_logout'),
     url(r'^accounts/profile/$', 'accounts.user_profile', name='user_profile'),
+    url(r'^accounts/profile/last_views$', 'accounts.last_views', name='user_last_views'),
+    url(r'^accounts/profile/votes$', 'accounts.votes', name='user_votes'),
     url(r'^accounts/register/$', 'accounts.user_registration', {'SSL': True}, name='user_registration'),
 
 
@@ -78,21 +78,24 @@ urlpatterns = patterns('hyperkitty.views',
         'thread.thread_index', name='thread'),
     url(r'^list/(?P<mlist_fqdn>[^/@]+@[^/@]+)/thread/(?P<threadid>\w+)/replies$',
         'thread.replies', name='thread_replies'),
-    url(r'^list/(?P<mlist_fqdn>[^/@]+@[^/@]+)/thread/(?P<threadid>\w+)/addtag$',
-        'thread.add_tag', name='add_tag'),
+    url(r'^list/(?P<mlist_fqdn>[^/@]+@[^/@]+)/thread/(?P<threadid>\w+)/tags$',
+        'thread.tags', name='tags'),
+    url(r'^list/(?P<mlist_fqdn>[^/@]+@[^/@]+)/thread/(?P<threadid>\w+)/suggest-tags$',
+        'thread.suggest_tags', name='suggest_tags'),
     url(r'^list/(?P<mlist_fqdn>[^/@]+@[^/@]+)/thread/(?P<threadid>\w+)/favorite$',
         'thread.favorite', name='favorite'),
+    url(r'^list/(?P<mlist_fqdn>[^/@]+@[^/@]+)/thread/(?P<threadid>\w+)/category$',
+        'thread.set_category', name='thread_set_category'),
+    url(r'^list/(?P<mlist_fqdn>[^/@]+@[^/@]+)/thread/(?P<threadid>\w+)/reattach$',
+        'thread.reattach', name='thread_reattach'),
+    url(r'^list/(?P<mlist_fqdn>[^/@]+@[^/@]+)/thread/(?P<threadid>\w+)/reattach-suggest$',
+        'thread.reattach_suggest', name='thread_reattach_suggest'),
 
 
-    # Search Tag
-    url(r'^list/(?P<mlist_fqdn>[^/@]+@[^/@]+)/tag/(?P<tag>.*)/$',
-        'list.search_tag', name='search_tag'),
-
     # Search
-    url(r'^list/(?P<mlist_fqdn>[^/@]+@[^/@]+)/search/(?P<target>.*)/(?P<keyword>.*)/$',
-        'list.search_keyword', name="search_keyword"),
-    url(r'^list/(?P<mlist_fqdn>[^/@]+@[^/@]+)/search/$',
-        'list.search', name="search_list"),
+    url(r'^search$', 'search.search', name='search'),
+    url(r'^list/(?P<mlist_fqdn>[^/@]+@[^/@]+)/tag/(?P<tag>.*)/$',
+        'search.search_tag', name='search_tag'),
 
 
     # REST API
@@ -105,6 +108,7 @@ urlpatterns = patterns('hyperkitty.views',
         ThreadResource.as_view(), name="api_thread"),
     url(r'^api/search\/(?P<mlist_fqdn>[^/@]+@[^/@]+)\/(?P<field>.*)\/(?P<keyword>.*)/',
         SearchResource.as_view(), name="api_search"),
+    url(r'^api/tag\/', TagResource.as_view(), name="api_tag"),
 
     # Uncomment the admin/doc line below to enable admin documentation:
     # url(r'^admin/doc/', include('django.contrib.admindocs.urls')),
