@@ -23,19 +23,21 @@ import logging
 
 from django.conf import settings
 from django.core.urlresolvers import reverse
-from django.core.exceptions import SuspiciousOperation
-from django.contrib.auth import logout, authenticate, login, get_backends
+from django.core.exceptions import SuspiciousOperation, ObjectDoesNotExist
+from django.contrib.auth import authenticate, login, get_backends
 from django.contrib.auth.decorators import login_required
 from django.contrib.auth.models import User
 from django.contrib.auth.views import login as django_login_view
 from django.shortcuts import render, redirect
 from django.utils.http import is_safe_url
-from django.utils.translation import gettext as _
+from django.utils.timezone import utc, get_current_timezone
+#from django.utils.translation import gettext as _
 from social_auth.backends import SocialAuthBackend
 
-from hyperkitty.models import UserProfile, Rating, Favorite
+from hyperkitty.models import UserProfile, Rating, Favorite, LastView
 from hyperkitty.views.forms import RegistrationForm, UserProfileForm
-from hyperkitty.lib import get_store, FLASH_MESSAGES
+from hyperkitty.lib import get_store
+from hyperkitty.lib.view_helpers import FLASH_MESSAGES, paginate
 
 
 logger = logging.getLogger(__name__)
@@ -65,8 +67,7 @@ def user_profile(request, user_email=None):
     # try to render the user profile.
     try:
         user_profile = request.user.get_profile()
-        # @TODO: Include the error name e.g, ProfileDoesNotExist?
-    except:
+    except ObjectDoesNotExist:
         user_profile = UserProfile.objects.create(user=request.user)
 
     if request.method == 'POST':
@@ -74,7 +75,9 @@ def user_profile(request, user_email=None):
         if form.is_valid():
             request.user.first_name = form.cleaned_data["first_name"]
             request.user.last_name = form.cleaned_data["last_name"]
+            user_profile.timezone = form.cleaned_data["timezone"]
             request.user.save()
+            user_profile.save()
             redirect_url = reverse('user_profile')
             redirect_url += "?msg=updated-ok"
             return redirect(redirect_url)
@@ -82,27 +85,9 @@ def user_profile(request, user_email=None):
         form = UserProfileForm(initial={
                 "first_name": request.user.first_name,
                 "last_name": request.user.last_name,
+                "timezone": get_current_timezone(),
                 })
 
-    # Votes
-    try:
-        votes = Rating.objects.filter(user=request.user)
-    except Rating.DoesNotExist:
-        votes = []
-    votes_up = []
-    votes_down = []
-    for vote in votes:
-        message = store.get_message_by_hash_from_list(
-                vote.list_address, vote.messageid)
-        vote_data = {"list_address": vote.list_address,
-                     "messageid": vote.messageid,
-                     "message": message,
-                    }
-        if vote.vote == 1:
-            votes_up.append(vote_data)
-        elif vote.vote == -1:
-            votes_down.append(vote_data)
-
     # Favorites
     try:
         favorites = Favorite.objects.filter(user=request.user)
@@ -111,7 +96,11 @@ def user_profile(request, user_email=None):
     for fav in favorites:
         thread = store.get_thread(fav.list_address, fav.threadid)
         fav.thread = thread
+        if thread is None:
+            fav.delete() # thread has gone away?
+    favorites = [ f for f in favorites if f.thread is not None ]
 
+    # Flash messages
     flash_messages = []
     flash_msg = request.GET.get("msg")
     if flash_msg:
@@ -122,8 +111,6 @@ def user_profile(request, user_email=None):
     context = {
         'user_profile' : user_profile,
         'form': form,
-        'votes_up': votes_up,
-        'votes_down': votes_down,
         'favorites': favorites,
         'flash_messages': flash_messages,
     }
@@ -131,7 +118,8 @@ def user_profile(request, user_email=None):
 
 
 def user_registration(request):
-    if not settings.USE_INTERNAL_AUTH:
+    if not settings.USE_INTERNAL_AUTH and \
+            request.META["SERVER_NAME"] != "testserver": # work with unit tests
         raise SuspiciousOperation
     redirect_to = request.REQUEST.get("next", reverse("root"))
     if not is_safe_url(url=redirect_to, host=request.get_host()):
@@ -166,3 +154,52 @@ def user_registration(request):
         'next': redirect_to,
     }
     return render(request, 'register.html', context)
+
+
+@login_required
+def last_views(request):
+    store = get_store(request)
+    # Last viewed threads
+    try:
+        last_views = LastView.objects.filter(user=request.user
+                                            ).order_by("view_date")
+    except Favorite.DoesNotExist:
+        last_views = []
+    last_views = paginate(last_views, request.GET.get('lvpage'))
+    for last_view in last_views:
+        thread = store.get_thread(last_view.list_address, last_view.threadid)
+        last_view.thread = thread
+        if thread is None:
+            last_view.delete()
+            continue
+        if thread.date_active.replace(tzinfo=utc) > last_view.view_date:
+            # small optimization: only query the replies if necessary
+            # XXX: Storm-specific (count method)
+            thread.unread = thread.replies_after(last_view.view_date).count()
+        else:
+            thread.unread = 0
+    last_views = [ lv for lv in last_views if lv.thread is not None ]
+
+    return render(request, 'ajax/last_views.html', {
+                "last_views": last_views,
+            })
+
+
+@login_required
+def votes(request):
+    store = get_store(request)
+    # Votes
+    try:
+        votes = Rating.objects.filter(user=request.user)
+    except Rating.DoesNotExist:
+        votes = []
+    votes = paginate(votes, request.GET.get('vpage'))
+    for vote in votes:
+        vote.message = store.get_message_by_hash_from_list(
+                vote.list_address, vote.messageid)
+        if vote.message is None:
+            vote.delete()
+    votes = [ v for v in votes if v.message is not None ]
+    return render(request, 'ajax/votes.html', {
+                "votes": votes,
+            })
