@@ -17,13 +17,16 @@
 # HyperKitty.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Author: Aamir Khan <syst3m.w0rm@gmail.com>
+# Author: Aurélien Bompard <abompard@fedoraproject.org>
 #
 
 from django import forms
 from django.core import validators
 from django.contrib.auth.models import User
 from django.utils.safestring import mark_safe
+from django.utils.translation import ugettext, ugettext_lazy
 
+from hyperkitty.models import UserProfile
 
 
 def isValidUsername(username):
@@ -61,6 +64,8 @@ class RegistrationForm(forms.Form):
 class UserProfileForm(forms.Form):
     first_name = forms.CharField()
     last_name = forms.CharField()
+    timezone = forms.ChoiceField(label="Time zone",
+                                 choices=UserProfile.TIMEZONES)
 
 
 
@@ -91,26 +96,31 @@ class AddTagForm(forms.Form):
                            'button_text': 'Add'}
                     )
                 )
-    from_url = forms.CharField(widget=forms.HiddenInput, required=False)
+    action = forms.CharField(widget=forms.HiddenInput, initial="add")
 
 
 
-class SearchForm(forms.Form):
-    target =  forms.CharField(label='', help_text=None,
-                widget=forms.Select(
-                    choices=(('Subject', 'Subject'),
-                            ('Content', 'Content'),
-                            ('SubjectContent', 'Subject & Content'),
-                            ('From', 'From'))
-                    )
-                )
-
-    keyword = forms.CharField(max_length=100,label='', help_text=None,
-                widget=forms.TextInput(
-                    attrs={'placeholder': 'Search this list.'}
-                    )
-                )
+class AttachmentFileInput(forms.FileInput):
+    attach_first_text = ugettext_lazy('Attach a file')
+    attach_another_text = ugettext_lazy('Attach another file')
+    rm_text = ugettext_lazy('Remove this file')
+    template = """
+<span class="attach-files-template">
+    %(input)s <a href="#" title="%(rm_text)s">(-)</a>
+</span>
+<span class="attach-files"></span>
+<a class="attach-files-first">%(attach_first_text)s</a>
+<a class="attach-files-add">%(attach_another_text)s</a>
+"""
 
+    def render(self, name, value, attrs=None):
+        substitutions = {
+            'attach_first_text': self.attach_first_text,
+            'attach_another_text': self.attach_another_text,
+            'rm_text': self.rm_text,
+        }
+        substitutions['input'] = super(AttachmentFileInput, self).render(name, value, attrs)
+        return mark_safe(self.template % substitutions)
 
 
 class ReplyForm(forms.Form):
@@ -118,7 +128,13 @@ class ReplyForm(forms.Form):
     subject = forms.CharField(label="", required=False,
             widget=forms.TextInput(attrs={ 'placeholder': 'New subject'}))
     message = forms.CharField(label="", widget=forms.Textarea)
+    attachment = forms.FileField(required=False, widget=AttachmentFileInput)
 
 class PostForm(forms.Form):
     subject = forms.CharField()
     message = forms.CharField(widget=forms.Textarea)
+    attachment = forms.FileField(required=False, label="",
+                                 widget=AttachmentFileInput)
+
+class CategoryForm(forms.Form):
+    category = forms.ChoiceField(label="", required=False)
