@@ -26,22 +26,29 @@ from collections import namedtuple, defaultdict
 from django.shortcuts import redirect, render
 from django.conf import settings
 from django.core.urlresolvers import reverse
-from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
 from django.utils import formats
 from django.utils.dateformat import format as date_format
+from django.utils.timezone import utc
 from django.http import Http404
 
 from hyperkitty.models import Tag, Favorite
-from hyperkitty.lib import get_months, get_store, get_display_dates, daterange
-from hyperkitty.lib import FLASH_MESSAGES
-from hyperkitty.lib.voting import get_votes
-from forms import SearchForm
+from hyperkitty.lib import get_store
+from hyperkitty.lib.view_helpers import FLASH_MESSAGES, paginate, \
+        get_category_widget, get_months, get_display_dates, daterange, \
+        is_thread_unread
+from hyperkitty.lib.voting import get_votes, set_message_votes, set_thread_votes
 
 
 if settings.USE_MOCKUPS:
     from hyperkitty.lib.mockup import generate_top_author, generate_thread_per_category
 
 
+Thread = namedtuple('Thread', [
+    "thread_id", "subject", "participants", "length", "date_active",
+    "likes", "dislikes", "likestatus", "category", "unread",
+    ])
+
+
 def archives(request, mlist_fqdn, year=None, month=None, day=None):
     if year is None and month is None:
         today = datetime.date.today()
@@ -75,39 +82,13 @@ def _thread_list(request, mlist, threads, template_name='thread_list.html', extr
     if mlist is None:
         raise Http404("No archived mailing-list by that name.")
     store = get_store(request)
-    search_form = SearchForm(auto_id=False)
 
     participants = set()
     for thread in threads:
         participants.update(thread.participants)
 
         # Votes
-        totalvotes = 0
-        totallikes = 0
-        totaldislikes = 0
-        for message_id_hash in thread.email_id_hashes:
-            likes, dislikes, myvote = get_votes(message_id_hash, request.user)
-            totallikes = totallikes + likes
-            totalvotes = totalvotes + likes + dislikes
-            totaldislikes = totaldislikes + dislikes
-            if message_id_hash == thread.thread_id:
-                # Starting email: same id as the thread_id
-                thread.myvote = myvote
-        try:
-            thread.likes = totallikes / totalvotes
-        except ZeroDivisionError:
-            thread.likes = 0
-        try:
-            thread.dislikes = totaldislikes / totalvotes
-        except ZeroDivisionError:
-            thread.dislikes = 0
-        thread.likestatus = "neutral"
-        if thread.likes - thread.dislikes >= 10:
-            thread.likestatus = "likealot"
-        elif thread.likes - thread.dislikes > 0:
-            thread.likestatus = "like"
-        #elif thread.likes - thread.dislikes < 0:
-        #    thread.likestatus = "dislike"
+        set_thread_votes(thread, request.user)
 
         # Favorites
         thread.favorite = False
@@ -128,17 +109,14 @@ def _thread_list(request, mlist, threads, template_name='thread_list.html', extr
         except Tag.DoesNotExist:
             thread.tags = []
 
-    all_threads = threads
-    paginator = Paginator(threads, 10)
-    page_num = request.GET.get('page')
-    try:
-        threads = paginator.page(page_num)
-    except PageNotAnInteger:
-        # If page is not an integer, deliver first page.
-        threads = paginator.page(1)
-    except EmptyPage:
-        # If page is out of range (e.g. 9999), deliver last page of results.
-        threads = paginator.page(paginator.num_pages)
+        # Category
+        thread.category_hk, thread.category_form = \
+                get_category_widget(request, thread.category)
+
+        # Unread status
+        thread.unread = is_thread_unread(request, mlist.name, thread)
+
+    threads = paginate(threads, request.GET.get('page'))
 
     flash_messages = []
     flash_msg = request.GET.get("msg")
@@ -149,8 +127,6 @@ def _thread_list(request, mlist, threads, template_name='thread_list.html', extr
 
     context = {
         'mlist' : mlist,
-        'current_page': page_num,
-        'search_form': search_form,
         'threads': threads,
         'participants': len(participants),
         'months_list': get_months(store, mlist.name),
@@ -163,27 +139,34 @@ def _thread_list(request, mlist, threads, template_name='thread_list.html', extr
 def overview(request, mlist_fqdn=None):
     if not mlist_fqdn:
         return redirect('/')
-    search_form = SearchForm(auto_id=False)
 
     # Get stats for last 30 days
     today = datetime.datetime.utcnow()
+    #today -= datetime.timedelta(days=365) #debug
     # the upper boundary is excluded in the search, add one day
     end_date = today + datetime.timedelta(days=1)
     begin_date = end_date - datetime.timedelta(days=32)
 
     store = get_store(request)
     mlist = store.get_list(mlist_fqdn)
-    threads_result = store.get_threads(list_name=mlist.name, start=begin_date,
-        end=end_date)
+    if mlist is None:
+        raise Http404("No archived mailing-list by that name.")
+    threads_result = store.get_threads(
+            list_name=mlist.name, start=begin_date, end=end_date)
 
     threads = []
-    Thread = namedtuple('Thread', ["thread_id", "subject", "participants",
-                                   "length", "date_active"])
     participants = set()
     for thread_obj in threads_result:
+        # Votes
+        set_thread_votes(thread_obj, request.user)
         thread = Thread(thread_obj.thread_id, thread_obj.subject,
                         thread_obj.participants, len(thread_obj),
-                        thread_obj.date_active)
+                        thread_obj.date_active.replace(tzinfo=utc),
+                        thread_obj.likes, thread_obj.dislikes,
+                        thread_obj.likestatus,
+                        get_category_widget(None, thread_obj.category)[0],
+                        is_thread_unread(request, mlist.name, thread_obj),
+                        )
         # Statistics on how many participants and threads this month
         participants.update(thread.participants)
         threads.append(thread)
@@ -203,11 +186,35 @@ def overview(request, mlist_fqdn=None):
     else:
         authors = []
 
+    # Top posters
+    top_posters = []
+    for poster in store.get_top_participants(list_name=mlist.name,
+                start=begin_date, end=end_date, limit=5):
+        top_posters.append({"name": poster[0], "email": poster[1],
+                            "count": poster[2]})
+
+    # Popular threads
+    pop_threads = sorted([ t for t in threads if t.likes - t.dislikes > 0 ],
+                         key=lambda t: t.likes - t.dislikes,
+                         reverse=True)
+
+    # Threads by category
+    threads_by_category = {}
+    for thread in active_threads:
+        if not thread.category:
+            continue
+        # don't use defaultdict, use .setdefault():
+        # http://stackoverflow.com/questions/4764110/django-template-cant-loop-defaultdict
+        if len(threads_by_category.setdefault(thread.category, [])) >= 5:
+            continue
+        threads_by_category[thread.category].append(thread)
+
     # List activity
     # Use get_messages and not get_threads to count the emails, because
     # recently active threads include messages from before the start date
     emails_in_month = store.get_messages(list_name=mlist.name,
                                          start=begin_date, end=end_date)
+    # graph
     dates = defaultdict(lambda: 0) # no activity by default
     # populate with all days before adding data.
     for single_date in daterange(begin_date, end_date):
@@ -225,85 +232,20 @@ def overview(request, mlist_fqdn=None):
                                kwargs={'mlist_fqdn': mlist.name})
     archives_baseurl = archives_baseurl.rpartition("/")[0]
 
-    # threads per category is the top thread titles in each category
-    if settings.USE_MOCKUPS:
-        threads_per_category = generate_thread_per_category()
-    else:
-        threads_per_category = {}
-
     context = {
+        'view_name': 'overview',
         'mlist' : mlist,
-        'search_form': search_form,
         'top_threads': top_threads[:5],
         'most_active_threads': active_threads[:5],
         'top_author': authors,
-        'threads_per_category': threads_per_category,
+        'top_posters': top_posters,
+        'pop_threads': pop_threads[:5],
+        'threads_by_category': threads_by_category,
         'months_list': get_months(store, mlist.name),
         'evolution': evolution,
         'days': days,
         'archives_baseurl': archives_baseurl,
+        'num_threads': len(threads),
+        'num_participants': len(participants),
     }
-    return render(request, "recent_activities.html", context)
-
-
-def search(request, mlist_fqdn):
-    keyword = request.GET.get('keyword')
-    target = request.GET.get('target')
-    page = request.GET.get('page')
-    if keyword and target:
-        url = reverse('search_keyword',
-                      kwargs={'mlist_fqdn': mlist_fqdn,
-                              'target': target,
-                              'keyword': keyword})
-        if page:
-            url += '%s/' % page
-    else:
-        url = reverse('search_list', kwargs={"mlist_fqdn": mlist_fqdn})
-    return redirect(url)
-
-
-def search_keyword(request, mlist_fqdn, target, keyword, page=1):
-    store = get_store(request)
-    ## Should we remove the code below?
-    ## If urls.py does it job we should never need it
-    if not keyword:
-        keyword = request.GET.get('keyword')
-    if not target:
-        target = request.GET.get('target')
-    if not target:
-        target = 'Subject'
-    regex = '%%%s%%' % keyword
-    list_name = mlist_fqdn.split('@')[0]
-    if target.lower() == 'subjectcontent':
-        threads = store.search_content_subject(mlist_fqdn, keyword)
-    elif target.lower() == 'subject':
-        threads = store.search_subject(mlist_fqdn, keyword)
-    elif target.lower() == 'content':
-        threads = store.search_content(mlist_fqdn, keyword)
-    elif target.lower() == 'from':
-        threads = store.search_sender(mlist_fqdn, keyword)
-
-    return _search_results_page(request, mlist_fqdn, threads, 'Search', page)
-
-
-def search_tag(request, mlist_fqdn, tag):
-    '''Returns threads having a particular tag'''
-    store = get_store(request)
-    mlist = store.get_list(mlist_fqdn)
-
-    try:
-        tags = Tag.objects.filter(tag=tag)
-    except Tag.DoesNotExist:
-        tags = {}
-
-    threads = []
-    for t in tags:
-        threads.append(store.get_thread(mlist_fqdn, t.threadid))
-
-    extra_context = {
-        "tag": tag,
-        "list_title": "Search results for tag \"%s\"" % tag,
-        "no_results_text": "for this tag",
-    }
-    return _thread_list(request, mlist, threads, extra_context=extra_context)
-
+    return render(request, "overview.html", context)
