@@ -22,21 +22,21 @@
 
 import urllib
 import datetime
-from collections import namedtuple
 
 import django.utils.simplejson as json
 from django.http import HttpResponse, Http404
 from django.shortcuts import redirect, render
-from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.core.exceptions import SuspiciousOperation
 from django.template import RequestContext, loader
 from django.contrib.auth.decorators import login_required
 
-from hyperkitty.lib import get_store, get_months, post_to_list, PostingFailed
+from hyperkitty.lib import get_store
+from hyperkitty.lib.view_helpers import get_months
+from hyperkitty.lib.posting import post_to_list, PostingFailed
 from hyperkitty.lib.voting import set_message_votes
 from hyperkitty.models import Rating
-from forms import SearchForm, ReplyForm, PostForm
+from forms import ReplyForm, PostForm
 
 
 def index(request, mlist_fqdn, message_id_hash):
@@ -44,7 +44,6 @@ def index(request, mlist_fqdn, message_id_hash):
     Displays a single message identified by its message_id_hash (derived from
     message_id)
     '''
-    search_form = SearchForm(auto_id=False)
     store = get_store(request)
     message = store.get_message_by_hash_from_list(mlist_fqdn, message_id_hash)
     if message is None:
@@ -130,13 +129,11 @@ def vote(request, mlist_fqdn, message_id_hash):
 
     # Extract all the votes for this message to refresh it
     set_message_votes(message, request.user)
-    FakeMList = namedtuple("MailingList", ["name"])
     t = loader.get_template('messages/like_form.html')
     html = t.render(RequestContext(request, {
             "object": message,
             "message_id_hash": message_id_hash,
-            "mlist": FakeMList(name=mlist_fqdn)}
-            ))
+            }))
 
     result = { "like": message.likes, "dislike": message.dislikes,
                "html": html, }
@@ -168,7 +165,8 @@ def reply(request, mlist_fqdn, message_id_hash):
         headers = {"In-Reply-To": "<%s>" % message.message_id,
                    "References": "<%s>" % message.message_id, }
     try:
-        post_to_list(request, mlist, subject, form.cleaned_data["message"], headers)
+        post_to_list(request, mlist, subject, form.cleaned_data["message"],
+                     headers, attachments=request.FILES.getlist('attachment'))
     except PostingFailed, e:
         return HttpResponse(str(e), content_type="text/plain", status=500)
 
@@ -179,7 +177,7 @@ def reply(request, mlist_fqdn, message_id_hash):
         "content": form.cleaned_data["message"],
         "level": message.thread_depth, # no need to increment, level = thread_depth - 1
     }
-    t = loader.get_template('messages/temp_message.html')
+    t = loader.get_template('ajax/temp_message.html')
     html = t.render(RequestContext(request, { 'email': reply }))
     result = {"result": "The reply has been sent successfully.",
               "message_html": html}
@@ -207,7 +205,8 @@ def new_message(request, mlist_fqdn):
             redirect_url += "?msg=sent-ok"
             try:
                 post_to_list(request, mlist, form.cleaned_data['subject'],
-                             form.cleaned_data["message"])
+                             form.cleaned_data["message"],
+                             attachments=request.FILES.getlist("attachment"))
             except PostingFailed, e:
                 failure = str(e)
             else:
